<?php

namespace App\Service\Action\Classes;

use App\Entity\User;
use App\Service\Action\BaseActionService;
use App\Service\Response\ResponseServiceInterface;
use Doctrine\Persistence\ManagerRegistry;
use Symfony\Bundle\SecurityBundle\Security;

class DeleteProfile extends BaseActionService
{
    private ?User $user;

    public function __construct(
        private ResponseServiceInterface $response,
        Security                         $security,
        private ManagerRegistry          $doctrine,
    )
    {
        $this->user = $security->getUser();
        parent::__construct($response);
    }

    /**
     * Деактивация учетной записи
     *
     * @return void
     */
    public function runAction(): void
    {
        try {
            $this->user->setDeleted(true);
            $em = $this->doctrine->getManager();
            $em->persist($this->user);
            $em->flush();
            $this->response->getResponse()->addMessage('Профиль удален');
        } catch (\Exception $exception) {
            $this->response->getResponse()->addError('Ошибка удаления профиля');
        }
    }

    public function validate(): bool
    {
        if ($this->user === null) {
            $this->response->getResponse()->addError('Вы не авторизованы');
            return false;
        }

        if ($this->user->isDeleted()) {
            $this->response->getResponse()->addError('Профиль уже удален');
            return false;
        }
        return true;
    }
}