<?php

namespace App\Service\Action\Classes;

use App\Entity\User;
use App\Service\Action\BaseActionService;
use App\Service\Response\ResponseServiceInterface;
use Symfony\Bundle\SecurityBundle\Security;
use Symfony\Component\Security\Http\Attribute\CurrentUser;
use Symfony\Component\Serializer\SerializerInterface;

class GetProfile extends BaseActionService
{
    private ?User $user;

    public function __construct(
        private ResponseServiceInterface $response,
        Security                         $security,
        private SerializerInterface      $serializer
    )
    {
        $this->user = $security->getUser();
        parent::__construct($response);
    }


    /**
     * Получение профиля пользователя
     *
     * @return void
     *
     * @throws \JsonException
     */
    public function runAction(): void
    {
        $serializedUser = $this->serializer->serialize($this->user, 'json', ['groups' => ['profile']]);
        $this->response->getResponse()->setResponseData(json_decode($serializedUser, true, 512, JSON_THROW_ON_ERROR));
    }

    public function validate(): bool
    {
        return $this->user->isConfirm() && !$this->user->isDeleted();
    }
}