<?php

namespace App\Service\Action\Classes;

use App\Entity\User;
use App\Service\Action\BaseActionService;
use App\Service\Dto\Classes\RecoveryDto;
use App\Service\Dto\DtoServiceInterface;
use App\Service\Response\ResponseServiceInterface;
use App\Service\Send\SendServiceInterface;
use Doctrine\Persistence\ManagerRegistry;

class RecoveryProfile extends BaseActionService
{
    /**
     * @param DtoServiceInterface $recoveryDto
     * @param ResponseServiceInterface $response
     * @param ManagerRegistry $doctrine
     */
    public function __construct(
        private DtoServiceInterface      $recoveryDto,
        private ResponseServiceInterface $response,
        private ManagerRegistry          $doctrine,
        private SendServiceInterface     $recoveryCodeSendService
    )
    {
        parent::__construct($response);
    }

    /**
     * Отправка кода восстановления учетной записи
     *
     * @return void
     */
    public function runAction(): void
    {
        /** @var RecoveryDto $dto */
        $dto = $this->recoveryDto->getClass();
        /** @var User $userExists */
        $userExists = $this->doctrine->getRepository(User::class)
            ->findOneByUniq($dto->email, $dto->phoneNumber);

        if ($userExists !== null) {
            if (!$userExists->isDeleted()) {
                $this->response->getResponse()->addError('Профиль не удален');
            } else {
                $this->recoveryCodeSendService->setUser($userExists);
                $this->recoveryCodeSendService->setResponse($this->response);
                $this->recoveryCodeSendService->send();
            }
        } else {
            $this->response->getResponse()->addError('Пользователь не найден');
        }
    }

    public function validate(): bool
    {
        return $this->recoveryDto->validate($this->response);
    }
}