<?php

namespace App\Service\Action\Classes;

use App\Entity\User;
use App\Service\Action\BaseActionService;
use App\Service\Response\ResponseServiceInterface;
use App\Service\Send\Classes\Code\RegisterCodeSendService;
use App\Service\Send\Classes\CodeSendService;
use App\Service\Send\SendServiceInterface;
use Symfony\Bundle\SecurityBundle\Security;

class SendRegisterCode extends BaseActionService
{
    private ?User $user;

    /**
     * @param ResponseServiceInterface $response
     * @param RegisterCodeSendService $registerCodeSendService
     * @param Security $security
     */
    public function __construct(
        private ResponseServiceInterface $response,
        private SendServiceInterface     $registerCodeSendService,
        Security                         $security
    )
    {
        $this->user = $security->getUser();
        parent::__construct($response);
    }


    /**
     * Отправка кода подтверждения регистрации
     *
     * @return void
     *
     * @throws \JsonException
     */
    public function runAction(): void
    {
        $this->registerCodeSendService->setUser($this->user);
        $this->registerCodeSendService->setResponse($this->response);
        $this->registerCodeSendService->send();
    }

    public function validate(): bool
    {
        if ($this->user === null) {
            $this->response->getResponse()->addError('Вы не авторизованы');
            return false;
        }
        if ($this->user->isConfirm()) {
            $this->response->getResponse()->addError('Учетная запись уже подтверждена');
            return false;
        }

        return true;
    }
}